@@ -114,6 +114,8 @@ typedef enum _MEDIA_EVENT_FILTER_KEYID
     TR_KEY_ENCODE_DATA_RECON_SURFACE,
     TR_KEY_ENCODE_DATA_BITSTREAM,
     TR_KEY_DECODE_DSTYUV_IN_TRACE,
+    TR_KEY_ENCODE_DATA_HUC_DMEM,
+    TR_KEY_ENCODE_DATA_HUC_REGION,
 } MEDIA_EVENT_FILTER_KEYID;
 
 #pragma pack(push, 8)
