@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2011-2019, Intel Corporation
+* Copyright (c) 2011-2021, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -32,6 +32,7 @@
 #include "codechal_setting.h"
 #include "codechal_hw.h"
 #include "codechal_debug.h"
+#include "codechal_oca_debug.h"
 #include "codechal_decode_downsampling.h"
 #include "codechal_decode_sfc.h"
 #include "codechal_mmc.h"
@@ -168,6 +169,10 @@ struct CodechalDecodeStatusReport
 #if (_DEBUG || _RELEASE_INTERNAL)
     //! \brief Applies when debug dumps are enabled, pointer to SFC output resource for the picture associated with this status report
     PMOS_RESOURCE           m_currSfcOutputPicRes = nullptr;
+    //! \brief Applies when debug dumps are enabled, pointer to histogram output resource for the picture associated with this status report
+    PMOS_RESOURCE           m_currHistogramOutBuf = nullptr;
+    //! \brief Applies when debug dumps are enabled, pointer to AV1 film grain output resource for the picture associated with this status report
+    PMOS_RESOURCE           m_currFgOutputPicRes = nullptr;
     //! \brief Applies when debug dumps are enabled, stream out buffer
     PMOS_RESOURCE           m_streamOutBuf = nullptr;
     //! \brief Applies when debug dumps are enabled, index of the streamout buffer
@@ -259,10 +264,10 @@ public:
     //!
     enum CodechalHcpDecodePhase
     {
-        CodechalHcpDecodePhaseInitialized = 0x00,   //!< Initial phase
-        CodechalHcpDecodePhaseLegacyLong,           //!< Legacy long format phase
-        CodechalHcpDecodePhaseLegacyS2L,            //!< Legacy short to long phase
-        CodechalHcpDecodePhaseMax                   //!< Maximal phases
+        CodechalHcpDecodePhaseInitialized = 0x00,  //!< Initial phase
+        CodechalHcpDecodePhaseLegacyLong,          //!< Legacy long format phase
+        CodechalHcpDecodePhaseLegacyS2L,           //!< Legacy short to long phase
+        CodechalHcpDecodePhaseMax                  //!< Maximal phases
     };
 
     //!
@@ -271,10 +276,10 @@ public:
     //!
     enum CodechalDecodeMotionType
     {
-        CodechalDecodeMcField   = 1,    //!< Field motion type
-        CodechalDecodeMcFrame   = 2,    //!< Frame motion type
-        CodechalDecodeMc16x8    = 2,    //!< 16x8 motion type
-        CodechalDecodeMcDmv     = 3     //!< DMV motion type
+        CodechalDecodeMcField = 1,  //!< Field motion type
+        CodechalDecodeMcFrame = 2,  //!< Frame motion type
+        CodechalDecodeMc16x8  = 2,  //!< 16x8 motion type
+        CodechalDecodeMcDmv   = 3   //!< DMV motion type
     };
 
     //!
@@ -283,14 +288,14 @@ public:
     //!
     enum CodechalDecodeMvPacking
     {
-        CodechalDecodeRstFirstForwHorz = 0, //!< first forward horizontal
-        CodechalDecodeRstFirstForwVert = 1, //!< first forward vertical
-        CodechalDecodeRstFirstBackHorz = 2, //!< first backward horizontal
-        CodechalDecodeRstFirstBackVert = 3, //!< first backward vertical
-        CodechalDecodeRstSecndForwHorz = 4, //!< second forward horizontal
-        CodechalDecodeRstSecndForwVert = 5, //!< second forward vertical
-        CodechalDecodeRstSecndBackHorz = 6, //!< second backward horizontal
-        CodechalDecodeRstSecndBackVert = 7  //!< second backward vertical
+        CodechalDecodeRstFirstForwHorz = 0,  //!< first forward horizontal
+        CodechalDecodeRstFirstForwVert = 1,  //!< first forward vertical
+        CodechalDecodeRstFirstBackHorz = 2,  //!< first backward horizontal
+        CodechalDecodeRstFirstBackVert = 3,  //!< first backward vertical
+        CodechalDecodeRstSecndForwHorz = 4,  //!< second forward horizontal
+        CodechalDecodeRstSecndForwVert = 5,  //!< second forward vertical
+        CodechalDecodeRstSecndBackHorz = 6,  //!< second backward horizontal
+        CodechalDecodeRstSecndBackVert = 7   //!< second backward vertical
     };
 
     //!
@@ -300,14 +305,14 @@ public:
     enum CodechalDecodeRefAddrIndex
     {
         // MPEG2/VC1 reference address indexes
-        CodechalDecodeFwdRefTop     = 0,    //!< forward reference top field
-        CodechalDecodeBwdRefTop     = 1,    //!< backward reference top field
-        CodechalDecodeFwdRefBottom  = 2,    //!< forward reference bottom field
-        CodechalDecodeBwdRefBottom  = 3,    //!< backward reference bottom field
+        CodechalDecodeFwdRefTop    = 0,  //!< forward reference top field
+        CodechalDecodeBwdRefTop    = 1,  //!< backward reference top field
+        CodechalDecodeFwdRefBottom = 2,  //!< forward reference bottom field
+        CodechalDecodeBwdRefBottom = 3,  //!< backward reference bottom field
         // VP8/VP9 reference address indexes
-        CodechalDecodeLastRef       = 0,    //!< last reference
-        CodechalDecodeGoldenRef     = 1,    //!< golden reference
-        CodechalDecodeAlternateRef  = 2     //!< alternate reference
+        CodechalDecodeLastRef      = 0,  //!< last reference
+        CodechalDecodeGoldenRef    = 1,  //!< golden reference
+        CodechalDecodeAlternateRef = 2   //!< alternate reference
     };
 
     //!
@@ -320,19 +325,19 @@ public:
     //!           The information of decode standard for this instance
     //!
     CodechalDecode(
-        CodechalHwInterface   *hwInterface,
-        CodechalDebugInterface* debugInterface,
+        CodechalHwInterface    *hwInterface,
+        CodechalDebugInterface *debugInterface,
         PCODECHAL_STANDARD_INFO standardInfo);
 
     //!
     //! \brief    Copy constructor
     //!
-    CodechalDecode(const CodechalDecode&) = delete;
+    CodechalDecode(const CodechalDecode &) = delete;
 
     //!
     //! \brief    Copy assignment operator
     //!
-    CodechalDecode& operator=(const CodechalDecode&) = delete;
+    CodechalDecode &operator=(const CodechalDecode &) = delete;
 
     //!
     //! \brief  Destructor
@@ -351,6 +356,11 @@ public:
     //!
     virtual uint32_t GetHeight() { return m_height; }
 
+    CodechalHwInterface *GetHwInterface()
+    {
+        return m_hwInterface;
+    }
+
     //!
     //! \brief  Help function to allocate a 1D linear buffer for each decode standard
     //! \param  [in,out] resource
@@ -398,6 +408,8 @@ public:
         MOS_FORMAT format = Format_NV12,
         bool isCompressible = false);
 
+    MOS_STATUS DestroySurface(PMOS_SURFACE surface);
+
     //!
     //! \brief  Entry to allocate and intialize the decode instance
     //! \param  [in] codecHalSettings
@@ -514,6 +526,15 @@ public:
     //!
     uint32_t GetMode() { return m_mode; }
 
+    //!
+    //! \brief  Get the perf profiler pointer
+    //! \return The perf profiler \see m_perfProfiler
+    //!
+    MediaPerfProfiler *GetPerfProfiler()
+    {
+        return m_perfProfiler;
+    }
+
     //!
     //! \brief  Gets the decode standard
     //! \return The decode standard \see m_standard
@@ -663,6 +684,8 @@ public:
     //!
     bool IsDecoderMmcEnabled(){return m_mmc ? m_mmc->IsMmcEnabled() : false;}
 
+    MOS_STATUS CheckDecodeOutputBufSize(MOS_SURFACE &dstSurface);
+
 protected:
 
     //!
@@ -801,7 +824,7 @@ protected:
 
 #if USE_CODECHAL_DEBUG_TOOL
     MOS_STATUS DumpProcessingParams(
-        PCODECHAL_DECODE_PROCESSING_PARAMS decProcParams);
+        DecodeProcessingParams *decProcParams);
 
 #endif
 
@@ -892,6 +915,8 @@ private:
         uint32_t allocWidth,
         uint32_t allocHeight,
         MOS_FORMAT format);
+
+    bool isSyncFreeNeededForMMCSurface(PMOS_SURFACE surface);
     //!
     //! \brief    Resize specific reference surfaces
     //! \details  Resize specific reference surfaces for decode downsampling for all codec types
@@ -911,6 +936,17 @@ private:
         uint32_t     width,
         uint32_t     height,
         MOS_FORMAT   format);
+
+   //!
+   //! \brief    Allocate Decode Output Buffer
+   //! \details  To Allocate Decode Output Buffer for media debug hook.
+   //! \param    dstSurface
+   //!           Decoded dstSurface
+   //! \return   MOS_STATUS
+   //!           MOS_STATUS_SUCCESS if success, else fail reason
+   //!
+   MOS_STATUS AllocateDecodeOutputBuf();
+
     //!
     //! \brief    Deallocate specific reference surfaces
     //! \details  Deallocate specific reference surfaces for decode downsampling for all codec types
@@ -1069,11 +1105,19 @@ protected:
     //! \brief Internal buffer for predication
     MOS_RESOURCE               m_predicationBuffer = { 0 };
 
+    MOS_RESOURCE               m_frameCountTypeBuf = { 0 };
+
+    MOS_RESOURCE               m_crcBuf = { 0 };
+
+    CodechalOcaDumper          *m_pCodechalOcaDumper = nullptr;
+
 #if (_DEBUG || _RELEASE_INTERNAL)
     //! \brief Downsampled surfaces
     PMOS_SURFACE                m_downsampledSurfaces = nullptr;
 #endif
+    uint8_t*                    m_decodeOutputBuf = nullptr;
 
+    uint32_t                    m_decodeOutputBufSize = 0;
     //! \brief    Decode histogram interface
     //! \details  Support YUV Luma histogram.
     CodechalDecodeHistogram    *m_decodeHistogram = nullptr;
@@ -1090,6 +1134,8 @@ protected:
 
     //! \brief Indicate the status of dummy reference
     CODECHAL_DUMMY_REFERENCE_STATUS m_dummyReferenceStatus = CODECHAL_DUMMY_REFERENCE_INVALID;
+
+    CodechalHwInterface* m_hwInterface = nullptr;
 };
 
 #endif  // __CODECHAL_DECODER_H__
