@@ -322,6 +322,8 @@ MOS_STATUS VpHal_RndrCommonSetPowerMode(
     RENDERHAL_POWEROPTION               PowerOption;
     bool                                bSetRequestedSlices     = false;
     const VphalSseuSetting              *pcSSEUTable            = nullptr;
+    MediaUserSettingSharedPtr           userSettingPtr          = nullptr;
+    uint32_t                            value                   = 0;
 
     VPHAL_RENDER_CHK_NULL(pRenderHal);
 
@@ -363,19 +365,17 @@ MOS_STATUS VpHal_RndrCommonSetPowerMode(
 
 #if (_DEBUG || _RELEASE_INTERNAL)
     // User feature key reads
-    MOS_USER_FEATURE_VALUE_DATA UserFeatureData;
-    MOS_ZeroMemory(&UserFeatureData, sizeof(UserFeatureData));
-    MOS_UserFeature_ReadValue_ID(
-        nullptr,
-        __MEDIA_USER_FEATURE_VALUE_SSEU_SETTING_OVERRIDE_ID,
-        &UserFeatureData,
-        pRenderHal->pOsInterface->pOsContext);
-
-    if (UserFeatureData.u32Data != 0xDEADC0DE)
+    userSettingPtr = pRenderHal->pOsInterface->pfnGetUserSettingInstance(pRenderHal->pOsInterface);
+    ReadUserSettingForDebug(
+        userSettingPtr,
+        value,
+        __MEDIA_USER_FEATURE_VALUE_SSEU_SETTING_OVERRIDE,
+        MediaUserSetting::Group::Device);
+    if (value != 0xDEADC0DE)
     {
-        wNumRequestedEUSlices  = UserFeatureData.u32Data & 0xFF;               // Bits 0-7
-        wNumRequestedSubSlices = (UserFeatureData.u32Data >> 8) & 0xFF;        // Bits 8-15
-        wNumRequestedEUs       = (UserFeatureData.u32Data >> 16) & 0xFFFF;     // Bits 16-31
+        wNumRequestedEUSlices  = value & 0xFF;               // Bits 0-7
+        wNumRequestedSubSlices = (value >> 8) & 0xFF;        // Bits 8-15
+        wNumRequestedEUs       = (value >> 16) & 0xFFFF;     // Bits 16-31
     }
 #endif
 
@@ -432,22 +432,24 @@ MOS_STATUS VpHal_RndrCommonSubmitCommands(
     MediaPerfProfiler                   *pPerfProfiler = nullptr;
     MOS_CONTEXT                         *pOsContext = nullptr;
     PMHW_MI_MMIOREGISTERS               pMmioRegisters = nullptr;
+    PRENDERHAL_INTERFACE_LEGACY         pRenderHalLegacy = (PRENDERHAL_INTERFACE_LEGACY)pRenderHal;
 
-    MHW_RENDERHAL_CHK_NULL(pRenderHal);
-    MHW_RENDERHAL_CHK_NULL(pRenderHal->pMhwRenderInterface);
-    MHW_RENDERHAL_CHK_NULL(pRenderHal->pMhwMiInterface);
-    MHW_RENDERHAL_CHK_NULL(pRenderHal->pMhwRenderInterface->GetMmioRegisters());
-    MHW_RENDERHAL_CHK_NULL(pRenderHal->pOsInterface);
-    MHW_RENDERHAL_CHK_NULL(pRenderHal->pOsInterface->pOsContext);
+    MHW_RENDERHAL_CHK_NULL(pRenderHalLegacy);
+    MHW_RENDERHAL_CHK_NULL(pRenderHalLegacy->pMhwRenderInterface);
+    MHW_RENDERHAL_CHK_NULL(pRenderHalLegacy->pMhwMiInterface);
+    MHW_RENDERHAL_CHK_NULL(pRenderHalLegacy->pMhwRenderInterface->GetMmioRegisters());
+    MHW_RENDERHAL_CHK_NULL(pRenderHalLegacy->pOsInterface);
+    MHW_RENDERHAL_CHK_NULL(pRenderHalLegacy->pOsInterface->pOsContext);
+    MHW_RENDERHAL_CHK_NULL(pRenderHalLegacy->pPerfProfiler);
 
     eStatus             = MOS_STATUS_UNKNOWN;
-    pOsInterface        = pRenderHal->pOsInterface;
-    pMhwMiInterface     = pRenderHal->pMhwMiInterface;
-    pMhwRender          = pRenderHal->pMhwRenderInterface;
+    pOsInterface        = pRenderHalLegacy->pOsInterface;
+    pMhwMiInterface     = pRenderHalLegacy->pMhwMiInterface;
+    pMhwRender          = pRenderHalLegacy->pMhwRenderInterface;
     iRemaining          = 0;
     FlushParam          = g_cRenderHal_InitMediaStateFlushParams;
     MOS_ZeroMemory(&CmdBuffer, sizeof(CmdBuffer));
-    pPerfProfiler       = pRenderHal->pPerfProfiler;
+    pPerfProfiler       = pRenderHalLegacy->pPerfProfiler;
     pOsContext          = pOsInterface->pOsContext;
     pMmioRegisters      = pMhwRender->GetMmioRegisters();
 
@@ -458,7 +460,7 @@ MOS_STATUS VpHal_RndrCommonSubmitCommands(
     iRemaining = CmdBuffer.iRemaining;
 
     VPHAL_RENDER_CHK_STATUS(VpHal_RndrCommonSetPowerMode(
-        pRenderHal,
+        pRenderHalLegacy,
         KernelID));
 
 #ifndef EMUL
@@ -481,31 +483,31 @@ MOS_STATUS VpHal_RndrCommonSubmitCommands(
 #endif
 
     HalOcaInterface::On1stLevelBBStart(CmdBuffer, *pOsContext, pOsInterface->CurrentGpuContextHandle,
-        *pRenderHal->pMhwMiInterface, *pMmioRegisters);
+        *pRenderHalLegacy->pMhwMiInterface, *pMmioRegisters);
 
     // Add kernel info to log.
-    HalOcaInterface::DumpVpKernelInfo(CmdBuffer, *pOsContext, KernelID, 0, nullptr);
+    HalOcaInterface::DumpVpKernelInfo(CmdBuffer, (MOS_CONTEXT_HANDLE)pOsContext, KernelID, 0, nullptr);
     // Add vphal param to log.
-    HalOcaInterface::DumpVphalParam(CmdBuffer, *pOsContext, pRenderHal->pVphalOcaDumper);
+    HalOcaInterface::DumpVphalParam(CmdBuffer, (MOS_CONTEXT_HANDLE)pOsContext, pRenderHalLegacy->pVphalOcaDumper);
 
     // Initialize command buffer and insert prolog
-    VPHAL_RENDER_CHK_STATUS(pRenderHal->pfnInitCommandBuffer(pRenderHal, &CmdBuffer, &GenericPrologParams));
+    VPHAL_RENDER_CHK_STATUS(pRenderHalLegacy->pfnInitCommandBuffer(pRenderHalLegacy, &CmdBuffer, &GenericPrologParams));
 
     // Write timing data for 3P budget
-    VPHAL_RENDER_CHK_STATUS(pRenderHal->pfnSendTimingData(pRenderHal, &CmdBuffer, true));
-    VPHAL_RENDER_CHK_STATUS(pPerfProfiler->AddPerfCollectStartCmd((void*)pRenderHal, pOsInterface, pMhwMiInterface, &CmdBuffer));
+    VPHAL_RENDER_CHK_STATUS(pRenderHalLegacy->pfnSendTimingData(pRenderHalLegacy, &CmdBuffer, true));
+    VPHAL_RENDER_CHK_STATUS(pPerfProfiler->AddPerfCollectStartCmd((void*)pRenderHalLegacy, pOsInterface, pMhwMiInterface, &CmdBuffer));
 
-    VPHAL_RENDER_CHK_STATUS(NullHW::StartPredicate(pRenderHal->pMhwMiInterface, &CmdBuffer));
+    VPHAL_RENDER_CHK_STATUS(NullHW::StartPredicate(pOsInterface, pRenderHalLegacy->pMhwMiInterface, &CmdBuffer));
 
     bEnableSLM = (pGpGpuWalkerParams && pGpGpuWalkerParams->SLMSize > 0)? true : false;
-    VPHAL_RENDER_CHK_STATUS(pRenderHal->pfnSetCacheOverrideParams(
-        pRenderHal,
-        &pRenderHal->L3CacheSettings,
+    VPHAL_RENDER_CHK_STATUS(pRenderHalLegacy->pfnSetCacheOverrideParams(
+        pRenderHalLegacy,
+        &pRenderHalLegacy->L3CacheSettings,
         bEnableSLM));
 
     // Flush media states
-    VPHAL_RENDER_CHK_STATUS(pRenderHal->pfnSendMediaStates(
-        pRenderHal,
+    VPHAL_RENDER_CHK_STATUS(pRenderHalLegacy->pfnSendMediaStates(
+        pRenderHalLegacy,
         &CmdBuffer,
         pWalkerParams,
         pGpGpuWalkerParams));
@@ -519,7 +521,7 @@ MOS_STATUS VpHal_RndrCommonSubmitCommands(
             false,
             true));
 
-        HalOcaInterface::OnSubLevelBBStart(CmdBuffer, *pOsContext, &pBatchBuffer->OsResource, 0, true, 0);
+        HalOcaInterface::OnSubLevelBBStart(CmdBuffer, (MOS_CONTEXT_HANDLE)pOsContext, &pBatchBuffer->OsResource, 0, true, 0);
 
         // Send Start 2nd level batch buffer command (HW/OS dependent)
         VPHAL_RENDER_CHK_STATUS(pMhwMiInterface->AddMiBatchBufferStartCmd(
@@ -530,17 +532,17 @@ MOS_STATUS VpHal_RndrCommonSubmitCommands(
     // Write back GPU Status tag
     if (!pOsInterface->bEnableKmdMediaFrameTracking)
     {
-        VPHAL_RENDER_CHK_STATUS(pRenderHal->pfnSendRcsStatusTag(pRenderHal, &CmdBuffer));
+        VPHAL_RENDER_CHK_STATUS(pRenderHalLegacy->pfnSendRcsStatusTag(pRenderHalLegacy, &CmdBuffer));
     }
 
-    VPHAL_RENDER_CHK_STATUS(NullHW::StopPredicate(pRenderHal->pMhwMiInterface, &CmdBuffer));
+    VPHAL_RENDER_CHK_STATUS(NullHW::StopPredicate(pOsInterface, pRenderHalLegacy->pMhwMiInterface, &CmdBuffer));
 
-    VPHAL_RENDER_CHK_STATUS(pPerfProfiler->AddPerfCollectEndCmd((void*)pRenderHal, pOsInterface, pMhwMiInterface, &CmdBuffer));
+    VPHAL_RENDER_CHK_STATUS(pPerfProfiler->AddPerfCollectEndCmd((void*)pRenderHalLegacy, pOsInterface, pMhwMiInterface, &CmdBuffer));
 
     // Write timing data for 3P budget
-    VPHAL_RENDER_CHK_STATUS(pRenderHal->pfnSendTimingData(pRenderHal, &CmdBuffer, false));
+    VPHAL_RENDER_CHK_STATUS(pRenderHalLegacy->pfnSendTimingData(pRenderHalLegacy, &CmdBuffer, false));
 
-    if (GFX_IS_GEN_9_OR_LATER(pRenderHal->Platform))
+    if (GFX_IS_GEN_9_OR_LATER(pRenderHalLegacy->Platform))
     {
         MHW_PIPE_CONTROL_PARAMS PipeControlParams;
 
@@ -551,7 +553,7 @@ MOS_STATUS VpHal_RndrCommonSubmitCommands(
         PipeControlParams.bDisableCSStall               = false;
         VPHAL_RENDER_CHK_STATUS(pMhwMiInterface->AddPipeControl(&CmdBuffer, nullptr, &PipeControlParams));
 
-        if (MEDIA_IS_WA(pRenderHal->pWaTable, WaSendDummyVFEafterPipelineSelect))
+        if (MEDIA_IS_WA(pRenderHalLegacy->pWaTable, WaSendDummyVFEafterPipelineSelect))
         {
             MHW_VFE_PARAMS VfeStateParams = {};
             VfeStateParams.dwNumberofURBEntries = 1;
@@ -559,10 +561,10 @@ MOS_STATUS VpHal_RndrCommonSubmitCommands(
         }
     }
 
-    if (GFX_IS_GEN_8_OR_LATER(pRenderHal->Platform))
+    if (GFX_IS_GEN_8_OR_LATER(pRenderHalLegacy->Platform))
     {
         // Add media flush command in case HW not cleaning the media state
-        if (MEDIA_IS_WA(pRenderHal->pWaTable, WaMSFWithNoWatermarkTSGHang))
+        if (MEDIA_IS_WA(pRenderHalLegacy->pWaTable, WaMSFWithNoWatermarkTSGHang))
         {
             FlushParam.bFlushToGo = true;
             if (pWalkerParams)
@@ -575,7 +577,7 @@ MOS_STATUS VpHal_RndrCommonSubmitCommands(
             }
             VPHAL_RENDER_CHK_STATUS(pMhwMiInterface->AddMediaStateFlush(&CmdBuffer, nullptr, &FlushParam));
         }
-        else if (MEDIA_IS_WA(pRenderHal->pWaTable, WaAddMediaStateFlushCmd))
+        else if (MEDIA_IS_WA(pRenderHalLegacy->pWaTable, WaAddMediaStateFlushCmd))
         {
             VPHAL_RENDER_CHK_STATUS(pMhwMiInterface->AddMediaStateFlush(&CmdBuffer, nullptr, &FlushParam));
         }
@@ -593,9 +595,9 @@ MOS_STATUS VpHal_RndrCommonSubmitCommands(
         // Send Batch Buffer end command for 1st level Batch Buffer
         VPHAL_RENDER_CHK_STATUS(pMhwMiInterface->AddMiBatchBufferEnd(&CmdBuffer, nullptr));
     }
-    else if (GFX_IS_GEN_8_OR_LATER(pRenderHal->Platform) &&
+    else if (GFX_IS_GEN_8_OR_LATER(pRenderHalLegacy->Platform) &&
                 Mos_Solo_IsInUse(pOsInterface) &&
-                pRenderHal->pOsInterface->bNoParsingAssistanceInKmd)
+                pRenderHalLegacy->pOsInterface->bNoParsingAssistanceInKmd)
     {
         VPHAL_RENDER_CHK_STATUS(pMhwMiInterface->AddMiBatchBufferEnd(&CmdBuffer, nullptr));
     }
@@ -610,10 +612,10 @@ MOS_STATUS VpHal_RndrCommonSubmitCommands(
 
     if (bNullRendering == false)
     {
-        dwSyncTag = pRenderHal->pStateHeap->dwNextTag++;
+        dwSyncTag = pRenderHalLegacy->pStateHeap->dwNextTag++;
 
         // Set media state and batch buffer as busy
-        pRenderHal->pStateHeap->pCurMediaState->bBusy = true;
+        pRenderHalLegacy->pStateHeap->pCurMediaState->bBusy = true;
         if (pBatchBuffer)
         {
             pBatchBuffer->bBusy     = true;
@@ -701,22 +703,24 @@ MOS_STATUS VpHal_RndrSubmitCommands(
     MediaPerfProfiler                   *pPerfProfiler = nullptr;
     MOS_CONTEXT                         *pOsContext = nullptr;
     PMHW_MI_MMIOREGISTERS               pMmioRegisters = nullptr;
+    PRENDERHAL_INTERFACE_LEGACY         pRenderHalLegacy = (PRENDERHAL_INTERFACE_LEGACY)pRenderHal;
 
-    MHW_RENDERHAL_CHK_NULL(pRenderHal);
-    MHW_RENDERHAL_CHK_NULL(pRenderHal->pMhwRenderInterface);
-    MHW_RENDERHAL_CHK_NULL(pRenderHal->pMhwMiInterface);
-    MHW_RENDERHAL_CHK_NULL(pRenderHal->pMhwRenderInterface->GetMmioRegisters());
-    MHW_RENDERHAL_CHK_NULL(pRenderHal->pOsInterface);
-    MHW_RENDERHAL_CHK_NULL(pRenderHal->pOsInterface->pOsContext);
+    MHW_RENDERHAL_CHK_NULL(pRenderHalLegacy);
+    MHW_RENDERHAL_CHK_NULL(pRenderHalLegacy->pMhwRenderInterface);
+    MHW_RENDERHAL_CHK_NULL(pRenderHalLegacy->pMhwMiInterface);
+    MHW_RENDERHAL_CHK_NULL(pRenderHalLegacy->pMhwRenderInterface->GetMmioRegisters());
+    MHW_RENDERHAL_CHK_NULL(pRenderHalLegacy->pOsInterface);
+    MHW_RENDERHAL_CHK_NULL(pRenderHalLegacy->pOsInterface->pOsContext);
+    MHW_RENDERHAL_CHK_NULL(pRenderHalLegacy->pPerfProfiler);
 
     eStatus              = MOS_STATUS_UNKNOWN;
-    pOsInterface         = pRenderHal->pOsInterface;
-    pMhwMiInterface      = pRenderHal->pMhwMiInterface;
-    pMhwRender           = pRenderHal->pMhwRenderInterface;
+    pOsInterface         = pRenderHalLegacy->pOsInterface;
+    pMhwMiInterface      = pRenderHalLegacy->pMhwMiInterface;
+    pMhwRender           = pRenderHalLegacy->pMhwRenderInterface;
     iRemaining           = 0;
     FlushParam           = g_cRenderHal_InitMediaStateFlushParams;
     MOS_ZeroMemory(&CmdBuffer, sizeof(CmdBuffer));
-    pPerfProfiler       = pRenderHal->pPerfProfiler;
+    pPerfProfiler       = pRenderHalLegacy->pPerfProfiler;
     pOsContext          = pOsInterface->pOsContext;
     pMmioRegisters      = pMhwRender->GetMmioRegisters();
 
@@ -727,7 +731,7 @@ MOS_STATUS VpHal_RndrSubmitCommands(
     iRemaining = CmdBuffer.iRemaining;
 
     VPHAL_RENDER_CHK_STATUS(VpHal_RndrCommonSetPowerMode(
-        pRenderHal,
+        pRenderHalLegacy,
         KernelID));
 
 #ifndef EMUL
@@ -751,40 +755,40 @@ MOS_STATUS VpHal_RndrSubmitCommands(
 #endif
 
     HalOcaInterface::On1stLevelBBStart(CmdBuffer, *pOsContext, pOsInterface->CurrentGpuContextHandle,
-        *pRenderHal->pMhwMiInterface, *pMmioRegisters);
+        *pRenderHalLegacy->pMhwMiInterface, *pMmioRegisters);
 
     // Add kernel info to log.
-    HalOcaInterface::DumpVpKernelInfo(CmdBuffer, *pOsContext, KernelID, FcKernelCount, FcKernelList);
+    HalOcaInterface::DumpVpKernelInfo(CmdBuffer, (MOS_CONTEXT_HANDLE)pOsContext, KernelID, FcKernelCount, FcKernelList);
     // Add vphal param to log.
-    HalOcaInterface::DumpVphalParam(CmdBuffer, *pOsContext, pRenderHal->pVphalOcaDumper);
+    HalOcaInterface::DumpVphalParam(CmdBuffer, (MOS_CONTEXT_HANDLE)pOsContext, pRenderHalLegacy->pVphalOcaDumper);
 
     // Initialize command buffer and insert prolog
-    VPHAL_RENDER_CHK_STATUS(pRenderHal->pfnInitCommandBuffer(pRenderHal, &CmdBuffer, &GenericPrologParams));
+    VPHAL_RENDER_CHK_STATUS(pRenderHalLegacy->pfnInitCommandBuffer(pRenderHalLegacy, &CmdBuffer, &GenericPrologParams));
 
-    VPHAL_RENDER_CHK_STATUS(pPerfProfiler->AddPerfCollectStartCmd((void*)pRenderHal, pOsInterface, pMhwMiInterface, &CmdBuffer));
+    VPHAL_RENDER_CHK_STATUS(pPerfProfiler->AddPerfCollectStartCmd((void*)pRenderHalLegacy, pOsInterface, pMhwMiInterface, &CmdBuffer));
 
-    VPHAL_RENDER_CHK_STATUS(NullHW::StartPredicate(pRenderHal->pMhwMiInterface, &CmdBuffer));
+    VPHAL_RENDER_CHK_STATUS(NullHW::StartPredicate(pOsInterface, pRenderHalLegacy->pMhwMiInterface, &CmdBuffer));
 
     // Write timing data for 3P budget
-    VPHAL_RENDER_CHK_STATUS(pRenderHal->pfnSendTimingData(pRenderHal, &CmdBuffer, true));
+    VPHAL_RENDER_CHK_STATUS(pRenderHalLegacy->pfnSendTimingData(pRenderHalLegacy, &CmdBuffer, true));
 
     bEnableSLM = (pGpGpuWalkerParams && pGpGpuWalkerParams->SLMSize > 0)? true : false;
-    VPHAL_RENDER_CHK_STATUS(pRenderHal->pfnSetCacheOverrideParams(
-        pRenderHal,
-        &pRenderHal->L3CacheSettings,
+    VPHAL_RENDER_CHK_STATUS(pRenderHalLegacy->pfnSetCacheOverrideParams(
+        pRenderHalLegacy,
+        &pRenderHalLegacy->L3CacheSettings,
         bEnableSLM));
 
-    if (pRenderHal->bCmfcCoeffUpdate)
+    if (pRenderHalLegacy->bCmfcCoeffUpdate)
     {
-        VPHAL_RENDER_CHK_STATUS(pRenderHal->pfnSendCscCoeffSurface(pRenderHal,
+        VPHAL_RENDER_CHK_STATUS(pRenderHalLegacy->pfnSendCscCoeffSurface(pRenderHalLegacy,
             &CmdBuffer,
-            pRenderHal->pCmfcCoeffSurface,
-            pRenderHal->pStateHeap->pKernelAllocation[pRenderHal->iKernelAllocationID].pKernelEntry));
+            pRenderHalLegacy->pCmfcCoeffSurface,
+            pRenderHalLegacy->pStateHeap->pKernelAllocation[pRenderHalLegacy->iKernelAllocationID].pKernelEntry));
     }
 
     // Flush media states
-    VPHAL_RENDER_CHK_STATUS(pRenderHal->pfnSendMediaStates(
-        pRenderHal,
+    VPHAL_RENDER_CHK_STATUS(pRenderHalLegacy->pfnSendMediaStates(
+        pRenderHalLegacy,
         &CmdBuffer,
         pWalkerParams,
         pGpGpuWalkerParams));
@@ -798,7 +802,7 @@ MOS_STATUS VpHal_RndrSubmitCommands(
             false,
             true));
 
-        HalOcaInterface::OnSubLevelBBStart(CmdBuffer, *pOsContext, &pBatchBuffer->OsResource, 0, true, 0);
+        HalOcaInterface::OnSubLevelBBStart(CmdBuffer, (MOS_CONTEXT_HANDLE)pOsContext, &pBatchBuffer->OsResource, 0, true, 0);
 
         // Send Start 2nd level batch buffer command (HW/OS dependent)
         VPHAL_RENDER_CHK_STATUS(pMhwMiInterface->AddMiBatchBufferStartCmd(
@@ -809,17 +813,17 @@ MOS_STATUS VpHal_RndrSubmitCommands(
     // Write back GPU Status tag
     if (!pOsInterface->bEnableKmdMediaFrameTracking)
     {
-        VPHAL_RENDER_CHK_STATUS(pRenderHal->pfnSendRcsStatusTag(pRenderHal, &CmdBuffer));
+        VPHAL_RENDER_CHK_STATUS(pRenderHalLegacy->pfnSendRcsStatusTag(pRenderHalLegacy, &CmdBuffer));
     }
 
-    VPHAL_RENDER_CHK_STATUS(NullHW::StopPredicate(pRenderHal->pMhwMiInterface, &CmdBuffer));
+    VPHAL_RENDER_CHK_STATUS(NullHW::StopPredicate(pOsInterface, pRenderHalLegacy->pMhwMiInterface, &CmdBuffer));
 
-    VPHAL_RENDER_CHK_STATUS(pPerfProfiler->AddPerfCollectEndCmd((void*)pRenderHal, pOsInterface, pMhwMiInterface, &CmdBuffer));
+    VPHAL_RENDER_CHK_STATUS(pPerfProfiler->AddPerfCollectEndCmd((void*)pRenderHalLegacy, pOsInterface, pMhwMiInterface, &CmdBuffer));
 
     // Write timing data for 3P budget
-    VPHAL_RENDER_CHK_STATUS(pRenderHal->pfnSendTimingData(pRenderHal, &CmdBuffer, false));
+    VPHAL_RENDER_CHK_STATUS(pRenderHalLegacy->pfnSendTimingData(pRenderHalLegacy, &CmdBuffer, false));
 
-    if (GFX_IS_GEN_9_OR_LATER(pRenderHal->Platform))
+    if (GFX_IS_GEN_9_OR_LATER(pRenderHalLegacy->Platform))
     {
         MHW_PIPE_CONTROL_PARAMS PipeControlParams;
 
@@ -830,7 +834,7 @@ MOS_STATUS VpHal_RndrSubmitCommands(
         PipeControlParams.bDisableCSStall               = false;
         VPHAL_RENDER_CHK_STATUS(pMhwMiInterface->AddPipeControl(&CmdBuffer, nullptr, &PipeControlParams));
 
-        if (MEDIA_IS_WA(pRenderHal->pWaTable, WaSendDummyVFEafterPipelineSelect))
+        if (MEDIA_IS_WA(pRenderHalLegacy->pWaTable, WaSendDummyVFEafterPipelineSelect))
         {
             MHW_VFE_PARAMS VfeStateParams = {};
             VfeStateParams.dwNumberofURBEntries = 1;
@@ -838,10 +842,10 @@ MOS_STATUS VpHal_RndrSubmitCommands(
         }
     }
 
-    if (GFX_IS_GEN_8_OR_LATER(pRenderHal->Platform))
+    if (GFX_IS_GEN_8_OR_LATER(pRenderHalLegacy->Platform))
     {
         // Add media flush command in case HW not cleaning the media state
-        if (MEDIA_IS_WA(pRenderHal->pWaTable, WaMSFWithNoWatermarkTSGHang))
+        if (MEDIA_IS_WA(pRenderHalLegacy->pWaTable, WaMSFWithNoWatermarkTSGHang))
         {
             FlushParam.bFlushToGo = true;
             if (pWalkerParams)
@@ -854,7 +858,7 @@ MOS_STATUS VpHal_RndrSubmitCommands(
             }
             VPHAL_RENDER_CHK_STATUS(pMhwMiInterface->AddMediaStateFlush(&CmdBuffer, nullptr, &FlushParam));
         }
-        else if (MEDIA_IS_WA(pRenderHal->pWaTable, WaAddMediaStateFlushCmd))
+        else if (MEDIA_IS_WA(pRenderHalLegacy->pWaTable, WaAddMediaStateFlushCmd))
         {
             VPHAL_RENDER_CHK_STATUS(pMhwMiInterface->AddMediaStateFlush(&CmdBuffer, nullptr, &FlushParam));
         }
@@ -872,9 +876,9 @@ MOS_STATUS VpHal_RndrSubmitCommands(
         // Send Batch Buffer end command for 1st level Batch Buffer
         VPHAL_RENDER_CHK_STATUS(pMhwMiInterface->AddMiBatchBufferEnd(&CmdBuffer, nullptr));
     }
-    else if (GFX_IS_GEN_8_OR_LATER(pRenderHal->Platform) &&
+    else if (GFX_IS_GEN_8_OR_LATER(pRenderHalLegacy->Platform) &&
                 Mos_Solo_IsInUse(pOsInterface)  &&
-                pRenderHal->pOsInterface->bNoParsingAssistanceInKmd)
+                pRenderHalLegacy->pOsInterface->bNoParsingAssistanceInKmd)
     {
         VPHAL_RENDER_CHK_STATUS(pMhwMiInterface->AddMiBatchBufferEnd(&CmdBuffer, nullptr));
     }
@@ -898,10 +902,10 @@ MOS_STATUS VpHal_RndrSubmitCommands(
 
     if (bNullRendering == false)
     {
-        dwSyncTag = pRenderHal->pStateHeap->dwNextTag++;
+        dwSyncTag = pRenderHalLegacy->pStateHeap->dwNextTag++;
 
         // Set media state and batch buffer as busy
-        pRenderHal->pStateHeap->pCurMediaState->bBusy = true;
+        pRenderHalLegacy->pStateHeap->pCurMediaState->bBusy = true;
         if (pBatchBuffer)
         {
             pBatchBuffer->bBusy     = true;
@@ -1179,6 +1183,9 @@ MOS_STATUS VpHal_RndrCommonSetBufferSurfaceForHwAccess(
     PRENDERHAL_SURFACE_STATE_ENTRY      pSurfaceEntry;
     MOS_STATUS                          eStatus;
 
+    VPHAL_RENDER_CHK_NULL(pRenderHal);
+    VPHAL_RENDER_CHK_NULL(pRenderHal->pOsInterface);
+
     // Initialize Variables
     eStatus                         = MOS_STATUS_SUCCESS;
     pOsInterface                    = pRenderHal->pOsInterface;
@@ -1200,6 +1207,12 @@ MOS_STATUS VpHal_RndrCommonSetBufferSurfaceForHwAccess(
     if (pSurfaceParams == nullptr)
     {
         MOS_ZeroMemory(&SurfaceParam, sizeof(SurfaceParam));
+
+        //set mem object control for cache
+        SurfaceParam.MemObjCtl = (pRenderHal->pOsInterface->pfnCachePolicyGetMemoryObject(
+            MOS_MP_RESOURCE_USAGE_DEFAULT,
+            pRenderHal->pOsInterface->pfnGetGmmClientContext(pRenderHal->pOsInterface))).DwordValue;
+
         pSurfaceParams = &SurfaceParam;
     }
 
@@ -1339,6 +1352,9 @@ MOS_STATUS VpHal_CommonSetBufferSurfaceForHwAccess(
     PRENDERHAL_SURFACE_STATE_ENTRY      pSurfaceEntry;
     MOS_STATUS                          eStatus;
 
+    VPHAL_RENDER_CHK_NULL(pRenderHal);
+    VPHAL_RENDER_CHK_NULL(pRenderHal->pOsInterface);
+
     // Initialize Variables
     eStatus                         = MOS_STATUS_SUCCESS;
     pOsInterface                    = pRenderHal->pOsInterface;
@@ -1355,6 +1371,12 @@ MOS_STATUS VpHal_CommonSetBufferSurfaceForHwAccess(
     if (pSurfaceParams == nullptr)
     {
         MOS_ZeroMemory(&SurfaceParam, sizeof(SurfaceParam));
+
+        //set mem object control for cache
+        SurfaceParam.MemObjCtl = (pRenderHal->pOsInterface->pfnCachePolicyGetMemoryObject(
+            MOS_MP_RESOURCE_USAGE_DEFAULT,
+            pRenderHal->pOsInterface->pfnGetGmmClientContext(pRenderHal->pOsInterface))).DwordValue;
+
         pSurfaceParams = &SurfaceParam;
     }
 
