@@ -449,7 +449,9 @@ MOS_STATUS HevcPipelineM12::Initialize(void *settings)
     DECODE_CHK_NULL(settings);
 
     DECODE_CHK_STATUS(MediaPipeline::InitPlatform());
-    DECODE_CHK_STATUS(MediaPipeline::CreateMediaCopy());
+    DECODE_CHK_STATUS(MediaPipeline::CreateMediaCopyWrapper());
+    DECODE_CHK_NULL(m_mediaCopyWrapper);
+    m_mediaCopyWrapper->CreateMediaCopyState();
 
     DECODE_CHK_NULL(m_waTable);
 
@@ -457,14 +459,14 @@ MOS_STATUS HevcPipelineM12::Initialize(void *settings)
     DECODE_CHK_NULL(m_hwInterface);
     DECODE_CHK_STATUS(m_hwInterface->Initialize(codecSettings));
 
-    if (m_mediaCopy == nullptr)
+    if (m_mediaCopyWrapper->MediaCopyStateIsNull())
     {
-        m_mediaCopy = m_hwInterface->CreateMediaCopy(m_osInterface);
+        m_mediaCopyWrapper->SetMediaCopyState(m_hwInterface->CreateMediaCopy(m_osInterface));
     }
 
 #if USE_CODECHAL_DEBUG_TOOL
     DECODE_CHK_NULL(m_debugInterface);
-    DECODE_CHK_STATUS(m_debugInterface->SetFastDumpConfig(m_mediaCopy));
+    DECODE_CHK_STATUS(m_debugInterface->SetFastDumpConfig(m_mediaCopyWrapper->GetMediaCopyState()));
 #endif
     if (m_hwInterface->m_hwInterfaceNext)
     {
@@ -656,7 +658,7 @@ MOS_STATUS HevcPipelineM12::DumpParams(HevcBasicFeature &basicFeature)
     m_debugInterface->m_frameType          = basicFeature.m_pictureCodingType;
 
     DECODE_CHK_STATUS(m_debugInterface->DumpBuffer(
-        &basicFeature.m_resDataBuffer.OsResource, CodechalDbgAttr::attrBitstream, "_DEC",
+        &basicFeature.m_resDataBuffer.OsResource, CodechalDbgAttr::attrDecodeBitstream, "_DEC",
         basicFeature.m_dataSize, 0, CODECHAL_NUM_MEDIA_STATES));
 
     DECODE_CHK_STATUS(DumpPicParams(
