@@ -385,8 +385,12 @@ MOS_STATUS Vp9DecodePicPktXe_M_Base::SetHcpRefSurfaceParams(MHW_VDBOX_SURFACE_PA
 #endif
     }
 #ifdef _MMC_SUPPORTED
-    Vp9DecodeMemComp *vp9DecodeMemComp = dynamic_cast<Vp9DecodeMemComp *>(m_mmcState);
-    DECODE_CHK_STATUS(vp9DecodeMemComp->SetRefSurfaceMask(*m_vp9BasicFeature, refSurfaceParams));
+    if (m_mmcState->IsMmcEnabled())
+    {
+        Vp9DecodeMemComp *vp9DecodeMemComp = dynamic_cast<Vp9DecodeMemComp *>(m_mmcState);
+        DECODE_CHK_STATUS(vp9DecodeMemComp->SetRefSurfaceMask(*m_vp9BasicFeature, refSurfaceParams));
+        DECODE_CHK_STATUS(vp9DecodeMemComp->SetRefSurfaceCompressionFormat(*m_vp9BasicFeature, refSurfaceParams));
+    }
 #endif
     return MOS_STATUS_SUCCESS;
 }
@@ -512,9 +516,14 @@ MOS_STATUS Vp9DecodePicPktXe_M_Base::SetHcpPipeBufAddrParams(MHW_VDBOX_PIPE_BUF_
     CODECHAL_DEBUG_TOOL(DumpRefResources(pipeBufAddrParams, m_vp9BasicFeature->m_resVp9MvTemporalBuffer[0]->size));
    
 #if MOS_EVENT_TRACE_DUMP_SUPPORTED
-    if (MOS_GetTraceEventKeyword() & EVENT_DECODE_REFYUV_KEYWORD)
+    if (MOS_TraceKeyEnabled(TR_KEY_DECODE_MV))
     {
-        TraceDataDumpRefResources(pipeBufAddrParams, m_vp9BasicFeature, m_vp9BasicFeature->m_resVp9MvTemporalBuffer[0]->size);
+        TraceDataDumpMV(pipeBufAddrParams, m_vp9BasicFeature->m_resVp9MvTemporalBuffer[0]->size);
+    }
+
+    if (MOS_TraceKeyEnabled(TR_KEY_DECODE_REFYUV))
+    {
+        TraceDataDumpReferences(pipeBufAddrParams);
     }
 #endif
 
@@ -650,7 +659,7 @@ MOS_STATUS Vp9DecodePicPktXe_M_Base::DumpRefResources(MHW_VDBOX_PIPE_BUF_ADDR_PA
             std::string refSurfName    = "RefSurf[" + std::to_string(static_cast<uint32_t>(debugInterface->m_refIndex)) + "]";
             DECODE_CHK_STATUS(debugInterface->DumpYUVSurface(
                 &dstSurface,
-                CodechalDbgAttr::attrReferenceSurfaces,
+                CodechalDbgAttr::attrDecodeReferenceSurfaces,
                 refSurfName.c_str()));
         }
     }
@@ -681,10 +690,44 @@ MOS_STATUS Vp9DecodePicPktXe_M_Base::DumpRefResources(MHW_VDBOX_PIPE_BUF_ADDR_PA
 #endif
 
 #if MOS_EVENT_TRACE_DUMP_SUPPORTED
-MOS_STATUS Vp9DecodePicPktXe_M_Base::TraceDataDumpRefResources(
+MOS_STATUS Vp9DecodePicPktXe_M_Base::TraceDataDumpMV(
     MHW_VDBOX_PIPE_BUF_ADDR_PARAMS &pipeBufAddrParams,
-    Vp9BasicFeature *m_vp9BasicFeature,
     uint32_t size)
+{
+    if (!m_allocator->ResourceIsNull(pipeBufAddrParams.presColMvTempBuffer[0]))
+    {
+        ResourceAutoLock resLock(m_allocator, pipeBufAddrParams.presColMvTempBuffer[0]);
+        auto             pData = (uint8_t *)resLock.LockResourceForRead();
+        DECODE_CHK_NULL(pData);
+
+        MOS_TraceDataDump(
+            "Decode_Vp9ColMvTempBuffer",
+            0,
+            pData,
+            size);
+
+        m_allocator->UnLock(pipeBufAddrParams.presColMvTempBuffer[0]);
+    };
+
+    if (!m_allocator->ResourceIsNull(pipeBufAddrParams.presCurMvTempBuffer))
+    {
+        ResourceAutoLock resLock(m_allocator, pipeBufAddrParams.presCurMvTempBuffer);
+        auto             pData = (uint8_t *)resLock.LockResourceForRead();
+        DECODE_CHK_NULL(pData);
+
+        MOS_TraceDataDump(
+            "Decode_Vp9CurMvTempBuffer",
+            0,
+            pData,
+            size);
+
+        m_allocator->UnLock(pipeBufAddrParams.presCurMvTempBuffer);
+    };
+
+    return MOS_STATUS_SUCCESS;
+}
+
+MOS_STATUS Vp9DecodePicPktXe_M_Base::TraceDataDumpReferences(MHW_VDBOX_PIPE_BUF_ADDR_PARAMS &pipeBufAddrParams)
 {
     bool bAllocateLastRef   = false;
     bool bAllocateGoldenRef = false;
@@ -750,16 +793,19 @@ MOS_STATUS Vp9DecodePicPktXe_M_Base::TraceDataDumpRefResources(
             m_tempLastRefSurf->UPlaneOffset.iSurfaceOffset,
             m_tempLastRefSurf->VPlaneOffset.iSurfaceOffset,
         };
-        MOS_TraceEvent(EVENT_DECODE_REF_DUMPINFO, EVENT_TYPE_INFO, &eventData, sizeof(eventData), NULL, 0);
+        MOS_TraceEvent(EVENT_DECODE_DUMPINFO_REF, EVENT_TYPE_INFO, &eventData, sizeof(eventData), NULL, 0);
 
         ResourceAutoLock resLock(m_allocator, &m_tempLastRefSurf->OsResource);
         auto             pData = (uint8_t *)resLock.LockResourceForRead();
+        DECODE_CHK_NULL(pData);
 
         MOS_TraceDataDump(
             "Decode_VP9LastRef",
             0, 
             pData,
             (uint32_t)m_tempLastRefSurf->OsResource.pGmmResInfo->GetSizeMainSurface());
+        
+        m_allocator->UnLock(&m_tempLastRefSurf->OsResource);
     }
 
     if (!m_allocator->ResourceIsNull(pipeBufAddrParams.presReferences[CodechalDecodeGoldenRef]))
@@ -822,16 +868,19 @@ MOS_STATUS Vp9DecodePicPktXe_M_Base::TraceDataDumpRefResources(
             m_tempGoldenRefSurf->UPlaneOffset.iSurfaceOffset,
             m_tempGoldenRefSurf->VPlaneOffset.iSurfaceOffset,
         };
-        MOS_TraceEvent(EVENT_DECODE_REF_DUMPINFO, EVENT_TYPE_INFO, &eventData, sizeof(eventData), NULL, 0);
+        MOS_TraceEvent(EVENT_DECODE_DUMPINFO_REF, EVENT_TYPE_INFO, &eventData, sizeof(eventData), NULL, 0);
 
         ResourceAutoLock resLock(m_allocator, &m_tempGoldenRefSurf->OsResource);
         auto             pData = (uint8_t *)resLock.LockResourceForRead();
+        DECODE_CHK_NULL(pData);
 
         MOS_TraceDataDump(
             "Decode_VP9GoldenRef",
             0,
             pData,
             (uint32_t)m_tempGoldenRefSurf->OsResource.pGmmResInfo->GetSizeMainSurface());
+        
+        m_allocator->UnLock(&m_tempGoldenRefSurf->OsResource);
     }
 
     if (!m_allocator->ResourceIsNull(pipeBufAddrParams.presReferences[CodechalDecodeAlternateRef]))
@@ -894,38 +943,21 @@ MOS_STATUS Vp9DecodePicPktXe_M_Base::TraceDataDumpRefResources(
             m_tempAltRefSurf->UPlaneOffset.iSurfaceOffset,
             m_tempAltRefSurf->VPlaneOffset.iSurfaceOffset,
         };
-        MOS_TraceEvent(EVENT_DECODE_REF_DUMPINFO, EVENT_TYPE_INFO, &eventData, sizeof(eventData), NULL, 0);
+        MOS_TraceEvent(EVENT_DECODE_DUMPINFO_REF, EVENT_TYPE_INFO, &eventData, sizeof(eventData), NULL, 0);
 
         ResourceAutoLock resLock(m_allocator, &m_tempAltRefSurf->OsResource);
         auto             pData = (uint8_t *)resLock.LockResourceForRead();
-
+        DECODE_CHK_NULL(pData);
+        
         MOS_TraceDataDump(
             "Decode_VP9AltRef",
             0,
             pData,
             (uint32_t)m_tempAltRefSurf->OsResource.pGmmResInfo->GetSizeMainSurface());
+        
+        m_allocator->UnLock(&m_tempAltRefSurf->OsResource);
     }
 
-    if (pipeBufAddrParams.presColMvTempBuffer[0])
-    {
-        m_osInterface->pfnDumpTraceGpuData(
-            m_osInterface,
-            "Decode_Vp9ColMvTempBuffer",
-            0,
-            pipeBufAddrParams.presColMvTempBuffer[0],
-            size);
-    };
-
-    if (pipeBufAddrParams.presCurMvTempBuffer)
-    {
-        m_osInterface->pfnDumpTraceGpuData(
-            m_osInterface,
-            "Decode_Vp9CurMvTempBuffer",
-            0,
-            pipeBufAddrParams.presCurMvTempBuffer,
-            size);
-    };
-
     return MOS_STATUS_SUCCESS;
 }
 #endif
