@@ -28,11 +28,18 @@
 #define __DECODE_STATUS_REPORT_H__
 
 #include "media_status_report.h"
-#include "decode_utils.h"
-#include "decode_allocator.h"
 #include "decode_status_report_defs.h"
+#include "codec_def_common.h"
+#include "media_class_trace.h"
+#include "mos_defs.h"
+#include "mos_os_specific.h"
+#include "decode_utils.h"
+#include <stdint.h>
+
+#define CODECHAL_DECODE_STATUS_NUM 512
 
 namespace decode {
+    class DecodeAllocator;
 
     //!
     //! \struct DecodeStatusReportData
@@ -80,7 +87,7 @@ namespace decode {
     class DecodeStatusReport : public MediaStatusReport
     {
     public:
-        DecodeStatusReport(DecodeAllocator *alloc, bool enableRcs);
+        DecodeStatusReport(DecodeAllocator *alloc, bool enableRcs, PMOS_INTERFACE osInterface = nullptr);
         virtual ~DecodeStatusReport();
 
         //!
@@ -187,8 +194,9 @@ namespace decode {
         PMOS_BUFFER            m_statusBufRcs = nullptr;
         uint8_t               *m_dataStatusMfx = nullptr;
         uint8_t               *m_dataStatusRcs = nullptr;
+        PMOS_INTERFACE        m_osInterface = nullptr;
 
-    MEDIA_CLASS_DEFINE_END(DecodeStatusReport)
+    MEDIA_CLASS_DEFINE_END(decode__DecodeStatusReport)
     };
 }
 
