@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2022, Intel Corporation
+* Copyright (c) 2022-2023, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -631,6 +631,12 @@ MOS_STATUS MosUserSetting::InitUserSettingForDebug(MediaUserSettingSharedPtr use
         MediaUserSetting::Group::Device,
         0,
         true);
+    DeclareUserSettingKeyForDebug(
+        userSettingPtr,
+        __MEDIA_USER_FEATURE_VALUE_IS_CODEC_ROW_STORE_CACHE_ENABLED,
+        MediaUserSetting::Group::Device,
+        0,
+        true);
     DeclareUserSettingKeyForDebug(
         userSettingPtr,
         "DisableVp9DfRowStoreCache",
@@ -1377,9 +1383,3 @@ MOS_STATUS MosUserSetting::InitUserSettingForDebug(MediaUserSettingSharedPtr use
 }
 
 #endif
-
-MOS_STATUS MosUserSetting::DestroyMediaUserSetting()
-{
-    MediaUserSetting::MediaUserSetting::Destroy();
-    return MOS_STATUS_SUCCESS;
-}
