@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2022, Intel Corporation
+* Copyright (c) 2022-2023, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -36,6 +36,7 @@
 #include "mhw_sfc_itf.h"
 #include "mhw_mi_itf.h"
 #include "vp_platform_interface.h"
+#include "vp_hal_ddi_utils.h"
 
 namespace vp {
 
@@ -323,6 +324,10 @@ MOS_STATUS SfcRenderBase::SetIefStateCscParams(
                 m_cscInputSwapNeeded = false;
             }
 
+            VP_RENDER_NORMALMESSAGE("sfc csc coeff calculated. (sfcInputCspace, cscRTCspace) current (%d, %d), previous (%d, %d), swap flag %d",
+                m_renderData.SfcInputCspace, m_renderData.pSfcPipeOutSurface->ColorSpace,
+                m_cscInputCspace, m_cscRTCspace, m_cscInputSwapNeeded ? 1 :0);
+
             m_cscInputCspace = m_renderData.SfcInputCspace;
             m_cscRTCspace    = m_renderData.pSfcPipeOutSurface->ColorSpace;
         }
@@ -342,10 +347,15 @@ MOS_STATUS SfcRenderBase::SetIefStateCscParams(
             m_cscCoeff[8]   = fTemp[2];
 
             m_cscInputSwapNeeded = IsInputChannelSwapNeeded(m_renderData.SfcInputFormat);
+
+            VP_RENDER_NORMALMESSAGE("sfc csc coeff swap flag need be updated to %d. sfcInputFormat %d, sfcInputCspace %d, cscRTCspace %d",
+                (m_cscInputSwapNeeded ? 1 : 0),
+                m_renderData.SfcInputFormat, m_cscInputCspace, m_cscRTCspace);
         }
         else
         {
-            VP_PUBLIC_NORMALMESSAGE("Keep the value of m_cscInputSwapNeeded.");
+            VP_RENDER_NORMALMESSAGE("sfc csc coeff reused. sfcInputFormat %d, sfcInputCspace %d, cscRTCspace %d, swap flag %d",
+                m_renderData.SfcInputFormat, m_cscInputCspace, m_cscRTCspace, (m_cscInputSwapNeeded ? 1 : 0));
         }
 
         pIEFStateParams->pfCscCoeff     = m_cscCoeff;
@@ -365,7 +375,8 @@ MOS_STATUS SfcRenderBase::SetIefStateParams(
 
     VP_RENDER_CHK_NULL_RETURN(psfcStateParams);
 
-    pIefStateParams = &m_IefStateParams;
+    auto &iefStateParams = m_sfcItf->MHW_GETPAR_F(SFC_IEF_STATE)();
+    pIefStateParams      = &iefStateParams;
     MOS_ZeroMemory(pIefStateParams, sizeof(*pIefStateParams));
     pIefStateParams->sfcPipeMode = m_pipeMode;
 
@@ -394,16 +405,21 @@ MOS_STATUS SfcRenderBase::SetAvsStateParams()
     MHW_SCALING_MODE            scalingMode        = MHW_SCALING_AVS;
     bool                        bUse8x8Filter      = false;
 
-    pMhwAvsState = &m_avsState.AvsStateParams;
+    auto &avsStateParams = m_sfcItf->MHW_GETPAR_F(SFC_AVS_STATE)();
+    pMhwAvsState         = &avsStateParams;
     MOS_ZeroMemory(pMhwAvsState, sizeof(MHW_SFC_AVS_STATE));
     pMhwAvsState->sfcPipeMode = m_pipeMode;
 
+    VP_RENDER_NORMALMESSAGE("bScaling %d, bForcePolyPhaseCoefs %d",
+        (m_renderData.bScaling ? 1 :0),
+        (m_renderData.bForcePolyPhaseCoefs ? 1 : 0));
+
     if (m_renderData.bScaling ||
         m_renderData.bForcePolyPhaseCoefs)
     {
         if (m_renderData.SfcSrcChromaSiting == MHW_CHROMA_SITING_NONE)
         {
-            if (VpUtils::GetSurfaceColorPack(m_renderData.SfcInputFormat) == VPHAL_COLORPACK_420) // For 420, default is Left & Center, else default is Left & Top
+            if (VpHalDDIUtils::GetSurfaceColorPack(m_renderData.SfcInputFormat) == VPHAL_COLORPACK_420) // For 420, default is Left & Center, else default is Left & Top
             {
                 m_renderData.SfcSrcChromaSiting = MHW_CHROMA_SITING_HORZ_LEFT | MHW_CHROMA_SITING_VERT_CENTER;
             }
@@ -449,12 +465,18 @@ MOS_STATUS SfcRenderBase::SetAvsStateParams()
             bUse8x8Filter = true;
         }
 
-        m_avsState.LumaCoeffs.sfcPipeMode   = m_pipeMode;
-        m_avsState.ChromaCoeffs.sfcPipeMode = m_pipeMode;
+        // directly get the par of SFC_AVS_LUMA_Coeff_Table_PAR  and initialize.
+        auto &lumaCoeffs = m_sfcItf->MHW_GETPAR_F(SFC_AVS_LUMA_Coeff_Table)();
+
+        // directly get the par of SFC_AVS_CHROMA_Coeff_Table  and initialize.
+        auto &chromaCoeffs = m_sfcItf->MHW_GETPAR_F(SFC_AVS_CHROMA_Coeff_Table)();
+
+        lumaCoeffs.sfcPipeMode              = m_pipeMode;
+        chromaCoeffs.sfcPipeMode            = m_pipeMode;
 
         VP_RENDER_CHK_STATUS_RETURN(SetSfcSamplerTable(
-            &m_avsState.LumaCoeffs,
-            &m_avsState.ChromaCoeffs,
+            &lumaCoeffs,
+            &chromaCoeffs,
             m_renderData.pAvsParams,
             m_renderData.SfcInputFormat,
             m_renderData.fScaleX,
@@ -564,6 +586,41 @@ MOS_STATUS SfcRenderBase::SetupSfcState(PVP_SURFACE targetSurface)
 
     VP_RENDER_CHK_STATUS_RETURN(SetupScalabilityParams());
 
+    // Decompress resource if surfaces need write from a un-align offset
+    if ((targetSurface->osSurface->CompressionMode != MOS_MMC_DISABLED)        &&
+        IsSFCUncompressedWriteNeeded(targetSurface))
+    {
+        MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
+        MOS_SURFACE details = {};
+
+        eStatus = m_osInterface->pfnGetResourceInfo(m_osInterface, &targetSurface->osSurface->OsResource, &details);
+
+        if (eStatus != MOS_STATUS_SUCCESS)
+        {
+            VP_RENDER_ASSERTMESSAGE("Get SFC target surface resource info failed.");
+        }
+
+        if (!targetSurface->osSurface->OsResource.bUncompressedWriteNeeded)
+        {
+            eStatus = m_osInterface->pfnDecompResource(m_osInterface, &targetSurface->osSurface->OsResource);
+
+            if (eStatus != MOS_STATUS_SUCCESS)
+            {
+                VP_RENDER_ASSERTMESSAGE("inplace decompression failed for sfc target.");
+            }
+            else
+            {
+                VP_RENDER_NORMALMESSAGE("inplace decompression enabled for sfc target RECT is not compression block align.");
+                targetSurface->osSurface->OsResource.bUncompressedWriteNeeded = 1;
+            }
+        }
+    }
+
+    if (targetSurface->osSurface->OsResource.bUncompressedWriteNeeded)
+    {
+        m_renderData.sfcStateParams->MMCMode = MOS_MMC_RC;
+    }
+
     return eStatus;
 }
 
@@ -653,6 +710,13 @@ MOS_STATUS SfcRenderBase::SetScalingParams(PSFC_SCALING_PARAMS scalingParams)
         VP_PUBLIC_CHK_STATUS_RETURN(MOS_STATUS_INVALID_PARAMETER);
     }
 
+    VP_RENDER_NORMALMESSAGE("fScaleX %f, fScaleY %f, bScaling %d, SfcScalingMode %d, SfcInputFormat %d, bRectangleEnabled",
+        m_renderData.fScaleX, m_renderData.fScaleY,
+        (m_renderData.bScaling ? 1 : 0),
+        m_renderData.SfcScalingMode,
+        m_renderData.SfcInputFormat,
+        (scalingParams->bRectangleEnabled ? 1: 0));
+
     return MOS_STATUS_SUCCESS;
 }
 
@@ -773,6 +837,22 @@ bool SfcRenderBase::IsInputChannelSwapNeeded(MOS_FORMAT inputFormat)
     }
 }
 
+MOS_STATUS SfcRenderBase::UpdateIefParams(PVPHAL_IEF_PARAMS iefParams)
+{
+    VP_FUNC_CALL();
+    m_renderData.bIEF           = (iefParams &&
+        iefParams->bEnabled &&
+        iefParams->fIEFFactor > 0.0F);
+    m_renderData.pIefParams     = iefParams;
+    return MOS_STATUS_SUCCESS;
+}
+
+MOS_STATUS SfcRenderBase::UpdateCscParams(FeatureParamCsc &cscParams)
+{
+    VP_RENDER_CHK_STATUS_RETURN(UpdateIefParams(cscParams.pIEFParams));
+    return MOS_STATUS_SUCCESS;
+}
+
 MOS_STATUS SfcRenderBase::SetCSCParams(PSFC_CSC_PARAMS cscParams)
 {
     VP_FUNC_CALL();
@@ -809,9 +889,6 @@ MOS_STATUS SfcRenderBase::SetCSCParams(PSFC_CSC_PARAMS cscParams)
     {
         m_renderData.sfcStateParams->ditheringEn = false;
     }
-    VP_PUBLIC_NORMALMESSAGE("cscParams.isDitheringNeeded = %d, m_disableSfcDithering = %d, ditheringEn = %d", 
-        cscParams->isDitheringNeeded, m_disableSfcDithering, m_renderData.sfcStateParams->ditheringEn);
-
 
     // Chromasitting config
     // VEBOX use polyphase coefficients for 1x scaling for better quality,
@@ -833,6 +910,10 @@ MOS_STATUS SfcRenderBase::SetCSCParams(PSFC_CSC_PARAMS cscParams)
     m_renderData.sfcStateParams->dwChromaDownSamplingHorizontalCoef = cscParams->chromaDownSamplingHorizontalCoef;
     m_renderData.sfcStateParams->dwChromaDownSamplingVerticalCoef   = cscParams->chromaDownSamplingVerticalCoef;
 
+    VP_RENDER_NORMALMESSAGE("cscParams.isDitheringNeeded %d, m_disableSfcDithering %d, ditheringEn %d, bForcePolyPhaseCoefs %d", 
+        cscParams->isDitheringNeeded, m_disableSfcDithering, m_renderData.sfcStateParams->ditheringEn,
+        (m_renderData.bForcePolyPhaseCoefs ? 1 : 0));
+
     return MOS_STATUS_SUCCESS;
 }
 
@@ -883,6 +964,11 @@ MOS_STATUS SfcRenderBase::SetMmcParams(PMOS_SURFACE renderTarget, bool isFormalM
     {
         m_renderData.sfcStateParams->bMMCEnable = true;
         m_renderData.sfcStateParams->MMCMode    = renderTarget->CompressionMode;
+
+        if (renderTarget->OsResource.bUncompressedWriteNeeded)
+        {
+            m_renderData.sfcStateParams->MMCMode = MOS_MMC_RC;
+        }
     }
     else
     {
@@ -899,7 +985,7 @@ MOS_STATUS SfcRenderBase::SetSfcStateInputChromaSubSampling(
     VP_FUNC_CALL();
 
     VP_PUBLIC_CHK_NULL_RETURN(sfcStateParams);
-    VPHAL_COLORPACK colorPack = VpUtils::GetSurfaceColorPack(m_renderData.SfcInputFormat);
+    VPHAL_COLORPACK colorPack = VpHalDDIUtils::GetSurfaceColorPack(m_renderData.SfcInputFormat);
     if (VPHAL_COLORPACK_400 == colorPack)
     {
         sfcStateParams->dwInputChromaSubSampling = MEDIASTATE_SFC_CHROMA_SUBSAMPLING_400;
@@ -1102,21 +1188,18 @@ MOS_STATUS SfcRenderBase::SendSfcCmd(
 
     // Send SFC_AVS_STATE command
     VP_RENDER_CHK_STATUS_RETURN(AddSfcAvsState(
-        pCmdBuffer,
-        &m_avsState.AvsStateParams));
+        pCmdBuffer));
 
     if (m_renderData.bScaling ||
         m_renderData.bForcePolyPhaseCoefs)
     {
         // Send SFC_AVS_LUMA_TABLE command
         VP_RENDER_CHK_STATUS_RETURN(AddSfcAvsLumaTable(
-            pCmdBuffer,
-            &m_avsState.LumaCoeffs));
+            pCmdBuffer));
 
         // Send SFC_AVS_CHROMA_TABLE command
         VP_RENDER_CHK_STATUS_RETURN(AddSfcAvsChromaTable(
-            pCmdBuffer,
-            &m_avsState.ChromaCoeffs));
+            pCmdBuffer));
     }
 
     // Send SFC_IEF_STATE command
@@ -1124,8 +1207,7 @@ MOS_STATUS SfcRenderBase::SendSfcCmd(
     {
         // Will modified when enable IEF/CSC
         VP_RENDER_CHK_STATUS_RETURN(AddSfcIefState(
-            pCmdBuffer,
-            &m_IefStateParams));
+            pCmdBuffer));
         //SETPAR_AND_ADDCMD(SFC_IEF_STATE, sfcItf, pCmdBuffer);
     }
 
@@ -1277,7 +1359,7 @@ uint32_t SfcRenderBase::GetSfdLineBufferSize(bool lineTiledBuffer, MOS_FORMAT fo
     // For VD+SFC mode, width needs be used. For VE+SFC mode, height needs be used.
     if (mhw::sfc::SFC_PIPE_MODE_VEBOX == m_pipeMode)
     {
-        size = (VPHAL_COLORPACK_444 == VpUtils::GetSurfaceColorPack(formatOutput)) ? 0 : (heightOutput * SFC_SFD_LINEBUFFER_SIZE_PER_PIXEL);
+        size = (VPHAL_COLORPACK_444 == VpHalDDIUtils::GetSurfaceColorPack(formatOutput)) ? 0 : (heightOutput * SFC_SFD_LINEBUFFER_SIZE_PER_PIXEL);
     }
     else
     {
@@ -1379,6 +1461,9 @@ MOS_STATUS SfcRenderBase::AllocateResources()
         VP_RENDER_CHK_NULL_RETURN(m_SFDLineBufferSurfaceArray);
     }
 
+    // for AVSLineBuffer, IEFLineBuffer and SFDLineBuffer, they are only needed when surface allocation bigger than 4150.
+    // for AVSLineTileBuffer, IEFLineTileBuffer and SFDLineTileBuffer, they are only needed for VdBox SFC scalability case and not needed for VeBox SFC case.
+
     // Allocate AVS Line Buffer surface----------------------------------------------
     size = GetAvsLineBufferSize(false, m_renderData.sfcStateParams->b8tapChromafiltering, m_renderData.sfcStateParams->dwInputFrameWidth, m_renderData.sfcStateParams->dwInputFrameHeight);
     VP_RENDER_CHK_STATUS_RETURN(AllocateLineBufferArray(m_AVSLineBufferSurfaceArray, size, "SfcAVSLineBufferSurface"));
@@ -1387,22 +1472,27 @@ MOS_STATUS SfcRenderBase::AllocateResources()
     size = GetIefLineBufferSize(false, m_renderData.sfcStateParams->dwScaledRegionHeight);
     VP_RENDER_CHK_STATUS_RETURN(AllocateLineBufferArray(m_IEFLineBufferSurfaceArray, size, "SfcIEFLineBufferSurface"));
 
-    // Allocate SFD Line Buffer surface
-    size = GetSfdLineBufferSize(false, m_renderData.sfcStateParams->OutputFrameFormat, m_renderData.sfcStateParams->dwScaledRegionWidth, m_renderData.sfcStateParams->dwScaledRegionHeight);
-    VP_RENDER_CHK_STATUS_RETURN(AllocateLineBufferArray(m_SFDLineBufferSurfaceArray, size, "SfcSFDLineBufferSurface"));
+    if (m_renderData.sfcStateParams->dwScaledRegionHeight > SFC_LINEBUFEER_SIZE_LIMITED)
+    {
+        // Allocate SFD Line Buffer surface
+        size = GetSfdLineBufferSize(false, m_renderData.sfcStateParams->OutputFrameFormat, m_renderData.sfcStateParams->dwScaledRegionWidth, m_renderData.sfcStateParams->dwScaledRegionHeight);
+        VP_RENDER_CHK_STATUS_RETURN(AllocateLineBufferArray(m_SFDLineBufferSurfaceArray, size, "SfcSFDLineBufferSurface"));
+    }
 
-    // Allocate AVS Line Tile Buffer surface----------------------------------------------
-    size = GetAvsLineBufferSize(true, m_renderData.sfcStateParams->b8tapChromafiltering, m_renderData.sfcStateParams->dwInputFrameWidth, m_renderData.sfcStateParams->dwInputFrameHeight);
-    VP_RENDER_CHK_STATUS_RETURN(AllocateLineBuffer(m_AVSLineTileBufferSurface, size, "SfcAVSLineTileBufferSurface"));
+    if (m_bVdboxToSfc)
+    {
+        // Allocate AVS Line Tile Buffer surface----------------------------------------------
+        size = GetAvsLineBufferSize(true, m_renderData.sfcStateParams->b8tapChromafiltering, m_renderData.sfcStateParams->dwInputFrameWidth, m_renderData.sfcStateParams->dwInputFrameHeight);
+        VP_RENDER_CHK_STATUS_RETURN(AllocateLineBuffer(m_AVSLineTileBufferSurface, size, "SfcAVSLineTileBufferSurface"));
 
-    // Allocate IEF Line Tile Buffer surface----------------------------------------------
-    size = GetIefLineBufferSize(true, m_renderData.sfcStateParams->dwScaledRegionHeight);
-    VP_RENDER_CHK_STATUS_RETURN(AllocateLineBuffer(m_IEFLineTileBufferSurface, size, "SfcIEFLineTileBufferSurface"));
-
-    // Allocate SFD Line Tile Buffer surface
-    size = GetSfdLineBufferSize(true, m_renderData.sfcStateParams->OutputFrameFormat, m_renderData.sfcStateParams->dwScaledRegionWidth, m_renderData.sfcStateParams->dwScaledRegionHeight);
-    VP_RENDER_CHK_STATUS_RETURN(AllocateLineBuffer(m_SFDLineTileBufferSurface, size, "SfcSFDLineTileBufferSurface"));
+        // Allocate IEF Line Tile Buffer surface----------------------------------------------
+        size = GetIefLineBufferSize(true, m_renderData.sfcStateParams->dwScaledRegionHeight);
+        VP_RENDER_CHK_STATUS_RETURN(AllocateLineBuffer(m_IEFLineTileBufferSurface, size, "SfcIEFLineTileBufferSurface"));
 
+        // Allocate SFD Line Tile Buffer surface
+        size = GetSfdLineBufferSize(true, m_renderData.sfcStateParams->OutputFrameFormat, m_renderData.sfcStateParams->dwScaledRegionWidth, m_renderData.sfcStateParams->dwScaledRegionHeight);
+        VP_RENDER_CHK_STATUS_RETURN(AllocateLineBuffer(m_SFDLineTileBufferSurface, size, "SfcSFDLineTileBufferSurface"));
+    }
     return MOS_STATUS_SUCCESS;
 }
 
@@ -1504,70 +1594,44 @@ MOS_STATUS SfcRenderBase::AddSfcState(
 }
 
 MOS_STATUS SfcRenderBase::AddSfcAvsState(
-    PMOS_COMMAND_BUFFER             pCmdBuffer,
-    mhw::sfc::SFC_AVS_STATE_PAR     *pSfcAvsStateParams)
+    PMOS_COMMAND_BUFFER             pCmdBuffer)
 {
     VP_FUNC_CALL();
-
-    VP_RENDER_CHK_NULL_RETURN(pSfcAvsStateParams);
     VP_RENDER_CHK_NULL_RETURN(m_sfcItf);
 
-    auto& params = m_sfcItf->MHW_GETPAR_F(SFC_AVS_STATE)();
-    params = {};
-    params = *pSfcAvsStateParams;
-
     VP_RENDER_CHK_STATUS_RETURN(m_sfcItf->MHW_ADDCMD_F(SFC_AVS_STATE)(pCmdBuffer));
 
     return MOS_STATUS_SUCCESS;
 }
 
 MOS_STATUS SfcRenderBase::AddSfcIefState(
-    PMOS_COMMAND_BUFFER            pCmdBuffer,
-    mhw::sfc::SFC_IEF_STATE_PAR    *pSfcIefStateParams)
+    PMOS_COMMAND_BUFFER            pCmdBuffer)
 {
     VP_FUNC_CALL();
-
-    VP_RENDER_CHK_NULL_RETURN(pSfcIefStateParams);
     VP_RENDER_CHK_NULL_RETURN(m_sfcItf);
 
-    auto& params = m_sfcItf->MHW_GETPAR_F(SFC_IEF_STATE)();
-    params = {};
-    params = *pSfcIefStateParams;
-
     VP_RENDER_CHK_STATUS_RETURN(m_sfcItf->MHW_ADDCMD_F(SFC_IEF_STATE)(pCmdBuffer));
 
     return MOS_STATUS_SUCCESS;
 }
 
 MOS_STATUS SfcRenderBase::AddSfcAvsLumaTable(
-    PMOS_COMMAND_BUFFER                pCmdBuffer,
-    mhw::sfc::SFC_AVS_LUMA_Coeff_Table_PAR *pLumaTable)
+    PMOS_COMMAND_BUFFER                pCmdBuffer)
 {
     VP_FUNC_CALL();
 
-    VP_RENDER_CHK_NULL_RETURN(pLumaTable);
     VP_RENDER_CHK_NULL_RETURN(m_sfcItf);
 
-    auto& params = m_sfcItf->MHW_GETPAR_F(SFC_AVS_LUMA_Coeff_Table)();
-    params = {};
-    params = *pLumaTable;
-
     VP_RENDER_CHK_STATUS_RETURN(m_sfcItf->MHW_ADDCMD_F(SFC_AVS_LUMA_Coeff_Table)(pCmdBuffer));
     return MOS_STATUS_SUCCESS;
 }
 
 MOS_STATUS SfcRenderBase::AddSfcAvsChromaTable(
-    PMOS_COMMAND_BUFFER             pCmdBuffer,
-    mhw::sfc::SFC_AVS_CHROMA_Coeff_Table_PAR       *pChromaTable)
+    PMOS_COMMAND_BUFFER             pCmdBuffer)
 {
     VP_FUNC_CALL();
-    VP_RENDER_CHK_NULL_RETURN(pChromaTable);
     VP_RENDER_CHK_NULL_RETURN(m_sfcItf);
 
-    auto& params = m_sfcItf->MHW_GETPAR_F(SFC_AVS_CHROMA_Coeff_Table)();
-    params = {};
-    params = *pChromaTable;
-
     VP_RENDER_CHK_STATUS_RETURN(m_sfcItf->MHW_ADDCMD_F(SFC_AVS_CHROMA_Coeff_Table)(pCmdBuffer));
 
     return MOS_STATUS_SUCCESS;
