@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2020-2021, Intel Corporation
+* Copyright (c) 2020-2022, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -25,12 +25,23 @@
 //! \details  render packet provide the structures and generate the cmd buffer which mediapipline will used.
 //!
 #include "vp_platform_interface.h"
-#include "cm_visa.h"
+#include "vp_visa.h"
+#include "vp_user_setting.h"
 
 using namespace vp;
-
+extern const Kdll_RuleEntry g_KdllRuleTable_Next[];
 const std::string VpRenderKernel::s_kernelNameNonAdvKernels = "vpFcKernels";
 
+VpPlatformInterface::VpPlatformInterface(PMOS_INTERFACE pOsInterface)
+{
+    m_pOsInterface = pOsInterface;
+    if (m_pOsInterface)
+    {
+        m_userSettingPtr = m_pOsInterface->pfnGetUserSettingInstance(m_pOsInterface);
+    }
+    VpUserSetting::InitVpUserSetting(m_userSettingPtr);
+}
+
 MOS_STATUS VpRenderKernel::InitVPKernel(
     const Kdll_RuleEntry *kernelRules,
     const uint32_t *      kernelBin,
@@ -93,7 +104,10 @@ MOS_STATUS VpRenderKernel::InitVPKernel(
         MOS_SafeFreeMemory(pKernelBin);
         MOS_SafeFreeMemory(pFcPatchBin);
     }
-    KernelDll_SetupFunctionPointers_Ext(m_kernelDllState);
+    else
+    {
+        KernelDll_SetupFunctionPointers_Ext(m_kernelDllState);
+    }
 
     SetKernelName(VpRenderKernel::s_kernelNameNonAdvKernels);
 
@@ -221,9 +235,133 @@ MOS_STATUS VpRenderKernel::AddKernelArg(KRN_ARG &kernelArg)
     return MOS_STATUS_SUCCESS;
 }
 
+void VpPlatformInterface::AddVpIsaKernelEntryToList(
+    const uint32_t *kernelBin,
+    uint32_t        kernelBinSize,
+    std::string     postfix,
+    DelayLoadedKernelType delayKernelType)
+{
+    VP_FUNC_CALL();
+
+    VP_KERNEL_BINARY_ENTRY tmpEntry = {};
+    tmpEntry.kernelBin     = kernelBin;
+    tmpEntry.kernelBinSize = kernelBinSize;
+    tmpEntry.postfix       = postfix;
+    tmpEntry.kernelType    = delayKernelType;
+
+    if (delayKernelType == KernelNone)
+    {
+        m_vpIsaKernelBinaryList.push_back(tmpEntry);
+    }
+    else
+    {
+        m_vpDelayLoadedBinaryList.push_back(tmpEntry);
+        m_vpDelayLoadedFeatureSet.insert(std::make_pair(delayKernelType, false));
+    }
+}
+
+void VpPlatformInterface::AddVpNativeAdvKernelEntryToList(
+    const uint32_t *kernelBin,
+    uint32_t        kernelBinSize,
+    std::string     kernelName)
+{
+    VP_FUNC_CALL();
+
+    VP_KERNEL_BINARY_ENTRY tmpEntry = {};
+    tmpEntry.kernelBin     = kernelBin;
+    tmpEntry.kernelBinSize = kernelBinSize;
+
+    m_vpNativeAdvKernelBinaryList.insert(std::make_pair(kernelName, tmpEntry));
+}
+
+void VpPlatformInterface::InitVpDelayedNativeAdvKernel(
+    const uint32_t *kernelBin,
+    uint32_t        kernelBinSize,
+    std::string     kernelName)
+{
+    VP_FUNC_CALL();
+
+    VP_KERNEL_BINARY_ENTRY tmpEntry = {};
+    tmpEntry.kernelBin              = kernelBin;
+    tmpEntry.kernelBinSize          = kernelBinSize;
+    InitVpNativeAdvKernels(kernelName, tmpEntry);
+}
+
+void VpPlatformInterface::AddNativeAdvKernelToDelayedList(
+    DelayLoadedKernelType kernelType,
+    DelayLoadedFunc       func)
+{
+    VP_FUNC_CALL();
+    m_vpDelayLoadedNativeFunctionSet.insert(std::make_pair(kernelType, func));
+}
+
+void       KernelDll_ModifyFunctionPointers_Next(Kdll_State *pState);
+
+MOS_STATUS VpPlatformInterface::InitVpRenderHwCaps()
+{
+    VP_FUNC_CALL();
+
+    if (m_isRenderDisabled)
+    {
+        VP_PUBLIC_NORMALMESSAGE("Bypass InitVpRenderHwCaps, since render disabled.");
+        return MOS_STATUS_SUCCESS;
+    }
+
+    VP_RENDER_CHK_NULL_RETURN(m_vpKernelBinary.kernelBin);
+    VP_RENDER_CHK_NULL_RETURN(m_vpKernelBinary.fcPatchKernelBin);
+    // Only Lpm Plus will use this base function
+    m_modifyKdllFunctionPointers = KernelDll_ModifyFunctionPointers_Next;
+#if defined(ENABLE_KERNELS)
+    InitVPFCKernels(
+        g_KdllRuleTable_Next,
+        m_vpKernelBinary.kernelBin,
+        m_vpKernelBinary.kernelBinSize,
+        m_vpKernelBinary.fcPatchKernelBin,
+        m_vpKernelBinary.fcPatchKernelBinSize,
+        m_modifyKdllFunctionPointers);
+#endif
+
+    if (!m_vpIsaKernelBinaryList.empty())
+    {
+        // Init CM kernel form VP ISA Kernel Binary List
+        for (auto &curKernelEntry : m_vpIsaKernelBinaryList)
+        {
+            VP_PUBLIC_CHK_STATUS_RETURN(InitVpCmKernels(curKernelEntry.kernelBin, curKernelEntry.kernelBinSize, curKernelEntry.postfix));
+        }
+    }
+
+    if (!m_vpNativeAdvKernelBinaryList.empty())
+    {
+        // Init native adv kernel form VP Native adv kernel Binary List
+        for (auto &curKernelEntry : m_vpNativeAdvKernelBinaryList)
+        {
+            VP_PUBLIC_CHK_STATUS_RETURN(InitVpNativeAdvKernels(curKernelEntry.first, curKernelEntry.second));
+        }
+    }
+    return MOS_STATUS_SUCCESS;
+}
+
+MOS_STATUS VpPlatformInterface::InitVpNativeAdvKernels(
+    std::string            kernelName,
+    VP_KERNEL_BINARY_ENTRY kernelBinaryEntry)
+{
+    VP_FUNC_CALL();
+
+    VpRenderKernel vpKernel;
+
+    vpKernel.SetKernelBinPointer((void *)kernelBinaryEntry.kernelBin);
+    vpKernel.SetKernelName(kernelName);
+    vpKernel.SetKernelBinOffset(0x0);
+    vpKernel.SetKernelBinSize(kernelBinaryEntry.kernelBinSize);
+    m_kernelPool.insert(std::make_pair(vpKernel.GetKernelName(), vpKernel));
+
+    return MOS_STATUS_SUCCESS;
+}
+
 MOS_STATUS VpPlatformInterface::InitVpCmKernels(
     const uint32_t *cisaCode,
-    uint32_t        cisaCodeSize)
+    uint32_t        cisaCodeSize,
+    std::string     postfix)
 {
     VP_FUNC_CALL();
     VP_RENDER_CHK_NULL_RETURN(cisaCode);
@@ -274,14 +412,19 @@ MOS_STATUS VpPlatformInterface::InitVpCmKernels(
         }
 
         std::string kernelName(kernel->getName(), kernel->getNameLen());
+        std::string fullKernelName = kernelName;
+        if (!postfix.empty())
+        {
+            fullKernelName += ('_' + postfix);
+        }
 
-        if (m_kernelPool.end() != m_kernelPool.find(kernelName))
+        if (m_kernelPool.end() != m_kernelPool.find(fullKernelName))
         {
             continue;
         }
 
         VpRenderKernel vpKernel;
-        vpKernel.SetKernelName(kernelName);
+        vpKernel.SetKernelName(fullKernelName);
         vpKernel.SetKernelBinPointer((void *)cisaCode);
 
         uint8_t          numGenBinaries = kernel->getNumGenBinaries();
@@ -367,6 +510,16 @@ VpPlatformInterface::~VpPlatformInterface()
     {
         kernel.second.Destroy();
     }
+
+    if (!m_vpDelayLoadedBinaryList.empty())
+    {
+        m_vpDelayLoadedBinaryList.clear();
+    }
+
+    if (!m_vpDelayLoadedNativeFunctionSet.empty())
+    {
+        m_vpDelayLoadedNativeFunctionSet.clear();
+    }
 }
 
 MOS_STATUS VpPlatformInterface::GetKernelParam(VpKernelID kernlId, RENDERHAL_KERNEL_PARAM &param)
@@ -377,6 +530,57 @@ MOS_STATUS VpPlatformInterface::GetKernelParam(VpKernelID kernlId, RENDERHAL_KER
     return MOS_STATUS_SUCCESS;
 }
 
+void VpPlatformInterface::SetVpFCKernelBinary(
+                const uint32_t   *kernelBin,
+                uint32_t         kernelBinSize,
+                const uint32_t   *fcPatchKernelBin,
+                uint32_t         fcPatchKernelBinSize)
+{
+    VP_FUNC_CALL();
+    
+    m_vpKernelBinary.kernelBin            = kernelBin;
+    m_vpKernelBinary.kernelBinSize        = kernelBinSize;
+    m_vpKernelBinary.fcPatchKernelBin     = fcPatchKernelBin;
+    m_vpKernelBinary.fcPatchKernelBinSize = fcPatchKernelBinSize;
+}
+
+MOS_STATUS VpPlatformInterface::InitializeDelayedKernels(DelayLoadedKernelType type)
+{
+    VP_FUNC_CALL();
+    auto feature = m_vpDelayLoadedFeatureSet.find(type);
+    if (feature != m_vpDelayLoadedFeatureSet.end() && feature->second == false && !m_vpDelayLoadedBinaryList.empty())
+    {
+        // Init CM kernel form VP ISA Kernel Binary List
+        for (auto it = m_vpDelayLoadedBinaryList.begin(); it != m_vpDelayLoadedBinaryList.end();)
+        {
+            if (it->kernelType == type)
+            {
+                VP_PUBLIC_CHK_STATUS_RETURN(InitVpCmKernels(it->kernelBin, it->kernelBinSize, it->postfix));
+                m_vpDelayLoadedBinaryList.erase(it);
+            }
+            else
+            {
+                ++it;
+            }
+        }
+        feature->second = true;
+    }
+
+    if (!m_vpDelayLoadedNativeFunctionSet.empty())
+    {
+        auto delayLoadedKernel = m_vpDelayLoadedNativeFunctionSet.find(type);
+        if (delayLoadedKernel != m_vpDelayLoadedNativeFunctionSet.end())
+        {
+            DelayLoadedFunc func = delayLoadedKernel->second;
+            VP_PUBLIC_CHK_NULL_RETURN(func);
+            func(*this);
+            m_vpDelayLoadedNativeFunctionSet.erase(delayLoadedKernel->first);
+        }
+    }
+
+    return MOS_STATUS_SUCCESS;
+}
+
 //only for get kernel binary in legacy path not being used in APO path.
 MOS_STATUS VpPlatformInterface ::GetKernelBinary(const void *&kernelBin, uint32_t &kernelSize, const void *&patchKernelBin, uint32_t &patchKernelSize)
 {
@@ -388,4 +592,58 @@ MOS_STATUS VpPlatformInterface ::GetKernelBinary(const void *&kernelBin, uint32_
     patchKernelSize = 0;
 
     return MOS_STATUS_SUCCESS;
-}
\ No newline at end of file
+}
+
+MOS_STATUS VpPlatformInterface::GetInputFrameWidthHeightAlignUnit(
+    PVP_MHWINTERFACE          pvpMhwInterface,
+    uint32_t                 &widthAlignUnit,
+    uint32_t                 &heightAlignUnit,
+    bool                      bVdbox,
+    CODECHAL_STANDARD         codecStandard,
+    CodecDecodeJpegChromaType jpegChromaType)
+{
+    VP_FUNC_CALL();
+
+    MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
+    VP_PUBLIC_CHK_NULL_RETURN(m_sfcItf);
+    VP_PUBLIC_CHK_STATUS_RETURN(m_sfcItf->GetInputFrameWidthHeightAlignUnit(widthAlignUnit, heightAlignUnit, bVdbox, codecStandard, jpegChromaType));
+
+    return eStatus;
+}
+
+MOS_STATUS VpPlatformInterface::GetVeboxHeapInfo(
+    PVP_MHWINTERFACE          pvpMhwInterface,
+    const MHW_VEBOX_HEAP    **ppVeboxHeap)
+{
+    VP_FUNC_CALL();
+
+    MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
+    const MHW_VEBOX_HEAP *pVeboxHeap = nullptr;
+    VP_PUBLIC_CHK_NULL_RETURN(m_veboxItf);
+
+    VP_RENDER_CHK_STATUS_RETURN(m_veboxItf->GetVeboxHeapInfo(
+        &pVeboxHeap));
+    *ppVeboxHeap = (const MHW_VEBOX_HEAP *)pVeboxHeap;
+
+    return eStatus;
+}
+
+bool VpPlatformInterface::IsVeboxScalabilityWith4KNotSupported(
+    VP_MHWINTERFACE          vpMhwInterface)
+{
+    if (m_veboxItf && !(m_veboxItf->IsVeboxScalabilitywith4K()))
+    {
+        return true;
+    }
+    else
+    {
+        return false;
+    }
+}
+
+void VpPlatformInterface::DisableRender()
+{
+    // media sfc interface should come to here.
+    VP_PUBLIC_NORMALMESSAGE("Disable Render.");
+    m_isRenderDisabled = true;
+}
