@@ -74,6 +74,15 @@ public:
 
     void Clear(void);
 
+    //!
+    //! \brief    Recreate GPU context as protected or clear if needed
+    //! \param    [in] streamState
+    //!           Os stream state
+    //! \return   MOS_STATUS
+    //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
+    //!
+    MOS_STATUS PatchGPUContextProtection(MOS_STREAM_HANDLE streamState);
+
     //!
     //! \brief    Register graphics resource
     //! \details  Set the Allocation Index in OS resource structure
@@ -173,6 +182,15 @@ public:
     //!
     uint32_t   GetGpuStatusTag() { return m_GPUStatusTag; }
 
+    //!
+    //! \brief    Get i915 ctx
+    //! \param    [in] ctxNodeIndex
+    //!           ctx index in array
+    //! \return   MOS_LINUX_CONTEXT
+    //!           mos linux ctx in array of ctxNodeIndex
+    //!
+    MOS_LINUX_CONTEXT* GetI915Context(uint32_t ctxNodeIndex){return ctxNodeIndex < (MAX_ENGINE_INSTANCE_NUM+1) ?  m_i915Context[ctxNodeIndex] : nullptr;}
+
     //!
     //! \brief    Increment GPU status tag
     //!
@@ -195,6 +213,12 @@ public:
     //!
     MOS_STATUS AllocateGPUStatusBuf();
 
+    //!
+    //! \brief    Store create options to member variable
+    //! \return   void
+    //!
+    void StoreCreateOptions(PMOS_GPUCTX_CREATOPTIONS createoption);
+
 #if MOS_COMMAND_RESINFO_DUMP_SUPPORTED
     void                PushCmdResPtr(const void *p) { m_cmdResPtrs.push_back(p); }
     void                ClearCmdResPtrs() { m_cmdResPtrs.clear(); }
@@ -260,6 +284,8 @@ protected:
         uint32_t *engineNum, uint32_t userEngineInstance, MOS_GPU_NODE gpuNode);
 #endif // _DEBUG || _RELEASE_INTERNAL
 
+    void UnlockPendingOcaBuffers(PMOS_COMMAND_BUFFER cmdBuffer, PMOS_CONTEXT mosContext);
+
 private:
     //! \brief    internal command buffer pool per gpu context
     std::vector<CommandBufferNext *> m_cmdBufPool;
@@ -302,9 +328,17 @@ private:
     uint32_t m_GPUStatusTag = 0;
 
     //! \brief    Os context
-    OsContextNext *m_osContext = nullptr;
+    OsContextNext *m_osContext      = nullptr;
+
+    //! \brief    mos context
+    PMOS_CONTEXT  m_osParameters    = nullptr;
+
+    MOS_GPUCTX_CREATOPTIONS_ENHANCED m_createOptionEnhanced;            //!< stores create otpions if user is using MOS_GPUCTX_CREATOPTIONS_ENHANCED
+    MOS_GPUCTX_CREATOPTIONS          m_createOption;                    //!< stores create otpions if user is using MOS_GPUCTX_CREATOPTIONS
+    bool                             m_bEnhancedUsed        = false;    //!< true if caller is using MOS_GPUCTX_CREATOPTIONS_ENHANCED,
+                                                                        //!< false if using MOS_GPUCTX_CREATOPTIONS
+    bool                             m_bProtectedContext    = false;    //!< false if clear GEM context is created as protected or not
 
-    MOS_GPUCTX_CREATOPTIONS_ENHANCED *m_createOptionEnhanced = nullptr;
     MOS_LINUX_CONTEXT*  m_i915Context[MAX_ENGINE_INSTANCE_NUM+1];
     uint32_t     m_i915ExecFlag = 0;
     int32_t      m_currCtxPriority = 0;
